pub struct JsFile { /* private fields */ }Expand description
This special wrapper used to verify the contents of JS files.
This struct is responsible for reading JS file from ./assets/js/* and verifying their contents match their hash when returned
Implementations