app_path2

Function app_path2 

pub fn app_path2(src: impl Into<String>, tail: impl Display) -> String
Returns the web facing path to a resource in your application Will be prefixed with the app_root takes two args useful when creating a path with an Id output: /app_root/src/tail