Module view

Module view 

Functions

app_path
Returns the web facing path to a resource in your application Will be prefixed with the app_root
app_path2
Returns the web facing path to a resource in your application Will be prefixed with the app_root takes two args useful when creating a path with an Id output: /app_root/src/tail
redirect
Render a Yew view to send out in an Actix Response Used when a form is not valid
render
Render a Yew view to send out in an Actix Response
render_min
Render a Yew view to send out in an Actix Response Strips out HTML comments
render_turbo_stream
Render a Yew view to send out in an Actix Response for a Turbo Stream
render_turbo_stream_full
Render a Yew view to send out in an Actix Response for a Turbo Stream return the full contents from YEW without stripping comments